pub struct BugReport {Show 31 fields
pub pending: Option<Pending>,
pub msgid: Option<String>,
pub owner: Option<String>,
pub keywords: Option<String>,
pub affects: Option<String>,
pub unarchived: Option<bool>,
pub forwarded: Option<String>,
pub summary: Option<String>,
pub bug_num: Option<BugId>,
pub archived: Option<bool>,
pub found_versions: Option<Vec<Version>>,
pub done: Option<String>,
pub severity: Option<String>,
pub package: Option<String>,
pub fixed_versions: Option<Vec<(Option<String>, Option<Version>)>>,
pub originator: Option<String>,
pub blocks: Option<String>,
pub found_date: Option<Vec<u32>>,
pub outlook: Option<String>,
pub id: Option<BugId>,
pub found: bool,
pub fixed: bool,
pub last_modified: Option<u32>,
pub tags: Option<String>,
pub subject: Option<String>,
pub location: Option<String>,
pub mergedwith: Option<Vec<BugId>>,
pub blockedby: Option<String>,
pub fixed_date: Option<Vec<u32>>,
pub log_modified: Option<u32>,
pub source: Option<String>,
}Expand description
Detailed information about a bug report
Contains comprehensive metadata about a bug including its status, severity, package information, and related bugs.
Fields
pending: Option<Pending>The pending status of the bug
msgid: Option<String>Message ID of the initial bug report email
owner: Option<String>Email address of the person who currently owns/is working on this bug
keywords: Option<String>Use tags instead
Keywords associated with the bug (deprecated, use tags instead)
affects: Option<String>Packages that are affected by this bug (in addition to the primary package)
unarchived: Option<bool>Whether the bug has been unarchived and can be archived again
forwarded: Option<String>Email address or URL where the bug has been forwarded to upstream
summary: Option<String>Short summary description of the bug
bug_num: Option<BugId>The unique bug number identifier
archived: Option<bool>Whether the bug has been archived (old/resolved bugs)
found_versions: Option<Vec<Version>>Versions of the package where this bug was found to exist
done: Option<String>Email address of the person who marked this bug as done/resolved
severity: Option<String>Severity level of the bug (e.g., “serious”, “important”, “normal”, “minor”, “wishlist”)
package: Option<String>Name of the package this bug affects
fixed_versions: Option<Vec<(Option<String>, Option<Version>)>>Versions of the package where this bug has been fixed
originator: Option<String>Email address of the person who originally reported this bug
blocks: Option<String>Comma-separated list of bug IDs that this bug blocks
found_date: Option<Vec<u32>>empty for now
Dates when the bug was found in specific versions (deprecated, currently empty)
outlook: Option<String>Free-form text describing the outlook for fixing this bug
id: Option<BugId>use bug_num
Legacy bug ID field (deprecated, use bug_num instead)
found: boolWhether the bug has been found in any versions
fixed: boolWhether the bug has been fixed in any versions
last_modified: Option<u32>Unix timestamp of when the bug was last modified
Space-separated list of tags associated with this bug
subject: Option<String>The title/subject line of the bug report
location: Option<String>Physical location or context information for the bug
mergedwith: Option<Vec<BugId>>List of bug IDs that this bug has been merged with
blockedby: Option<String>Comma-separated list of bug IDs that block this bug
fixed_date: Option<Vec<u32>>empty for now
Dates when the bug was fixed in specific versions (deprecated, currently empty)
log_modified: Option<u32>Unix timestamp of when the bug log was last modified
source: Option<String>Source package name (for binary packages built from source)